#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 show
version:              0.6
visibility:           public
id:                   show-0.6-FbSA4lJbpryKIC9UgLNB6M
key:                  show-0.6-FbSA4lJbpryKIC9UgLNB6M
license:              LicenseRef-GPL
maintainer:           Lambdabot developers
author:               Lambdabot devs, Twan van Laarhoven <twanvl@gmail.com>
stability:            Experimental
synopsis:             '\''Show'\'' instances for Lambdabot
description:          Show instances for functions and IO procedures
category:             Language
abi:                  bda071285e2cf57ea7aa8fa7f8e06fd6
exposed:              True
exposed-modules:      ShowFun
import-dirs:          /usr/lib/ghc-9.6.6/site-local/show-0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/show-0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/show-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-show
hs-libraries:         HSshow-0.6-FbSA4lJbpryKIC9UgLNB6M
depends:              base-4.18.2.1 syb-0.7.3-6KcX3BjpG2VC96bdiog9fw
haddock-interfaces:   /usr/share/doc/haskell-show/html/show.haddock
haddock-html:         /usr/share/doc/haskell-show/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

